# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dbtlabs/proto/public/v1/fields/vscode_types.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1dbtlabs/proto/public/v1/fields/vscode_types.proto\x12\x1dv1.public.fields.vscode_types\"u\n\x04User\x12\x1a\n\x12\x63redentials_source\x18\x01 \x01(\t\x12\x19\n\x11\x64\x62t_cloud_user_id\x18\x02 \x01(\t\x12\x1a\n\x12\x64\x62t_cloud_hostname\x18\x03 \x01(\t\x12\x1a\n\x12registration_state\x18\x04 \x01(\t\"\x90\x01\n\x06\x45\x64itor\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x12\n\nmachine_id\x18\x02 \x01(\t\x12\x16\n\x0emac_machine_id\x18\x03 \x01(\t\x12\x19\n\x11\x65xtension_version\x18\x04 \x01(\t\x12\x13\n\x0b\x65\x64itor_name\x18\x05 \x01(\t\x12\x16\n\x0e\x65\x64itor_version\x18\x06 \x01(\t\"-\n\x0c\x43ompileError\x12\x0f\n\x07message\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\x05*\x97\x01\n\tUserState\x12\x1b\n\x17USER_STATE_UNREGISTERED\x10\x00\x12\x19\n\x15USER_STATE_REGISTERED\x10\x01\x12\x17\n\x13USER_STATE_VERIFIED\x10\x02\x12\x16\n\x12USER_STATE_EXPIRED\x10\x03\x12!\n\x1dUSER_STATE_VERIFICATION_ERROR\x10\x04*(\n\x0b\x43ompileType\x12\x08\n\x04\x46ULL\x10\x00\x12\x0f\n\x0bSPECULATIVE\x10\x01*t\n\x0c\x43ompileCause\x12\x1a\n\x16\x43OMPILE_CAUSE_DID_SAVE\x10\x00\x12%\n!COMPILE_CAUSE_COMPILE_LSP_COMMAND\x10\x01\x12!\n\x1d\x43OMPILE_CAUSE_REFRESH_SOURCES\x10\x02*\x9c\x01\n\x19RegistrationTriggerMethod\x12+\n\'REGISTRATION_TRIGGER_METHOD_UNSPECIFIED\x10\x00\x12-\n)REGISTRATION_TRIGGER_METHOD_DBT_CLOUD_YML\x10\x01\x12#\n\x1fREGISTRATION_TRIGGER_METHOD_WEB\x10\x02*\xaa\x01\n\x12RegistrationMethod\x12#\n\x1fREGISTRATION_METHOD_UNSPECIFIED\x10\x00\x12%\n!REGISTRATION_METHOD_DBT_CLOUD_YML\x10\x01\x12\x1d\n\x19REGISTRATION_METHOD_OAUTH\x10\x02\x12)\n%REGISTRATION_METHOD_REGISTRATION_CODE\x10\x03\x42@Z>github.com/dbt-labs/proto-golang/v1/public/fields/vscode_typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dbtlabs.proto.public.v1.fields.vscode_types_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z>github.com/dbt-labs/proto-golang/v1/public/fields/vscode_types'
  _globals['_USERSTATE']._serialized_start=398
  _globals['_USERSTATE']._serialized_end=549
  _globals['_COMPILETYPE']._serialized_start=551
  _globals['_COMPILETYPE']._serialized_end=591
  _globals['_COMPILECAUSE']._serialized_start=593
  _globals['_COMPILECAUSE']._serialized_end=709
  _globals['_REGISTRATIONTRIGGERMETHOD']._serialized_start=712
  _globals['_REGISTRATIONTRIGGERMETHOD']._serialized_end=868
  _globals['_REGISTRATIONMETHOD']._serialized_start=871
  _globals['_REGISTRATIONMETHOD']._serialized_end=1041
  _globals['_USER']._serialized_start=84
  _globals['_USER']._serialized_end=201
  _globals['_EDITOR']._serialized_start=204
  _globals['_EDITOR']._serialized_end=348
  _globals['_COMPILEERROR']._serialized_start=350
  _globals['_COMPILEERROR']._serialized_end=395
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import dbtlabs.proto.public.v1.common.vortex_telemetry_contexts_pb2
import dbtlabs.proto.public.v1.events.vortex_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class ToolCalled(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class ArgumentsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ENRICHMENT_FIELD_NUMBER: builtins.int
    EVENT_ID_FIELD_NUMBER: builtins.int
    START_TIME_MS_FIELD_NUMBER: builtins.int
    END_TIME_MS_FIELD_NUMBER: builtins.int
    TOOL_NAME_FIELD_NUMBER: builtins.int
    ARGUMENTS_FIELD_NUMBER: builtins.int
    ERROR_MESSAGE_FIELD_NUMBER: builtins.int
    DBT_CLOUD_ENVIRONMENT_ID_DEV_FIELD_NUMBER: builtins.int
    DBT_CLOUD_ENVIRONMENT_ID_PROD_FIELD_NUMBER: builtins.int
    DBT_CLOUD_USER_ID_FIELD_NUMBER: builtins.int
    LOCAL_USER_ID_FIELD_NUMBER: builtins.int
    HOST_FIELD_NUMBER: builtins.int
    MULTICELL_ACCOUNT_PREFIX_FIELD_NUMBER: builtins.int
    CTX_FIELD_NUMBER: builtins.int
    DBT_MCP_VERSION_FIELD_NUMBER: builtins.int
    AUTHENTICATION_METHOD_FIELD_NUMBER: builtins.int
    TRACE_ID_FIELD_NUMBER: builtins.int
    DISABLED_TOOLSETS_FIELD_NUMBER: builtins.int
    DISABLED_TOOLS_FIELD_NUMBER: builtins.int
    USER_AGENT_FIELD_NUMBER: builtins.int
    event_id: builtins.str
    """event_id is the unique identifier for this event. It is a generated UUID."""
    start_time_ms: builtins.int
    """The start of the tool call in milliseconds since the Unix epoch"""
    end_time_ms: builtins.int
    """The end of the tool call in milliseconds since the Unix epoch"""
    tool_name: builtins.str
    """The name of the tool, e.g. get_dimentions, dbt build, get_mart_models"""
    error_message: builtins.str
    """An error message if the call fails"""
    dbt_cloud_environment_id_dev: builtins.str
    """The user can optionally set their dev environment id to use tools like the execute_sql"""
    dbt_cloud_environment_id_prod: builtins.str
    """The user can optionally set their prod environment id to use tools like list_metrics"""
    dbt_cloud_user_id: builtins.str
    """The user can optionally set their user id to use tools like execute_sql"""
    local_user_id: builtins.str
    """The user id found at ~/.dbt/.user.yml if present"""
    host: builtins.str
    """The dbt Cloud host that the user configured"""
    multicell_account_prefix: builtins.str
    """The multicell account prefix that the user configured: https://docs.getdbt.com/docs/cloud/about-cloud/access-regions-ip-addresses"""
    dbt_mcp_version: builtins.str
    """The version of dbt_mcp being used (e.g. 0.8.2)"""
    authentication_method: builtins.str
    """How the instance of dbt-mcp was authenticated. Only applicable to local MCP (e.g. env-vars, oauth, null)"""
    trace_id: builtins.str
    """The trace that this tool call is associated with, i.e., the tools it is called with for a single user message. Only applicable to tool calls within an agent run in the dbt Platform."""
    user_agent: builtins.str
    """Indicates where this request is coming from with the user_agent header. This is only relevant for remote MCP. For local MCP, the user_agent can be attained from the enrichment field."""
    @property
    def enrichment(self) -> dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment: ...
    @property
    def arguments(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """The arguments supplied to the tool, e.g. a list of metrics or a dbt CLI selector"""

    @property
    def ctx(self) -> dbtlabs.proto.public.v1.common.vortex_telemetry_contexts_pb2.VortexTelemetryDbtCloudContext:
        """Common dbt Platform context"""

    @property
    def disabled_toolsets(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """The list of disabled toolsets from the DISABLE_* environment variables or x-dbt-disable-toolsets header."""

    @property
    def disabled_tools(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """This list of disabled tools from the DISABLE_TOOLS environment variable or x-dbt-disable-tools header."""

    def __init__(
        self,
        *,
        enrichment: dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment | None = ...,
        event_id: builtins.str = ...,
        start_time_ms: builtins.int = ...,
        end_time_ms: builtins.int = ...,
        tool_name: builtins.str = ...,
        arguments: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        error_message: builtins.str = ...,
        dbt_cloud_environment_id_dev: builtins.str = ...,
        dbt_cloud_environment_id_prod: builtins.str = ...,
        dbt_cloud_user_id: builtins.str = ...,
        local_user_id: builtins.str = ...,
        host: builtins.str = ...,
        multicell_account_prefix: builtins.str = ...,
        ctx: dbtlabs.proto.public.v1.common.vortex_telemetry_contexts_pb2.VortexTelemetryDbtCloudContext | None = ...,
        dbt_mcp_version: builtins.str = ...,
        authentication_method: builtins.str = ...,
        trace_id: builtins.str = ...,
        disabled_toolsets: collections.abc.Iterable[builtins.str] | None = ...,
        disabled_tools: collections.abc.Iterable[builtins.str] | None = ...,
        user_agent: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["ctx", b"ctx", "enrichment", b"enrichment"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["arguments", b"arguments", "authentication_method", b"authentication_method", "ctx", b"ctx", "dbt_cloud_environment_id_dev", b"dbt_cloud_environment_id_dev", "dbt_cloud_environment_id_prod", b"dbt_cloud_environment_id_prod", "dbt_cloud_user_id", b"dbt_cloud_user_id", "dbt_mcp_version", b"dbt_mcp_version", "disabled_tools", b"disabled_tools", "disabled_toolsets", b"disabled_toolsets", "end_time_ms", b"end_time_ms", "enrichment", b"enrichment", "error_message", b"error_message", "event_id", b"event_id", "host", b"host", "local_user_id", b"local_user_id", "multicell_account_prefix", b"multicell_account_prefix", "start_time_ms", b"start_time_ms", "tool_name", b"tool_name", "trace_id", b"trace_id", "user_agent", b"user_agent"]) -> None: ...

Global___ToolCalled: typing_extensions.TypeAlias = ToolCalled



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dbtlabs/proto/public/v1/events/fusion/log/list_item.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n9dbtlabs/proto/public/v1/events/fusion/log/list_item.proto\x12\x1bv1.public.events.fusion.log\"\x8d\x01\n\x0eListItemOutput\x12\x44\n\routput_format\x18\x01 \x01(\x0e\x32-.v1.public.events.fusion.log.ListOutputFormat\x12\x0f\n\x07\x63ontent\x18\x02 \x01(\t\x12\x16\n\tunique_id\x18\x03 \x01(\tH\x00\x88\x01\x01\x42\x0c\n\n_unique_id*\xae\x01\n\x10ListOutputFormat\x12\"\n\x1eLIST_OUTPUT_FORMAT_UNSPECIFIED\x10\x00\x12\x1b\n\x17LIST_OUTPUT_FORMAT_JSON\x10\x01\x12\x1f\n\x1bLIST_OUTPUT_FORMAT_SELECTOR\x10\x02\x12\x1b\n\x17LIST_OUTPUT_FORMAT_NAME\x10\x03\x12\x1b\n\x17LIST_OUTPUT_FORMAT_PATH\x10\x04\x42>Z<github.com/dbt-labs/proto-golang/v1/public/events/fusion/logb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dbtlabs.proto.public.v1.events.fusion.log.list_item_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z<github.com/dbt-labs/proto-golang/v1/public/events/fusion/log'
  _globals['_LISTOUTPUTFORMAT']._serialized_start=235
  _globals['_LISTOUTPUTFORMAT']._serialized_end=409
  _globals['_LISTITEMOUTPUT']._serialized_start=91
  _globals['_LISTITEMOUTPUT']._serialized_end=232
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dbtlabs/proto/public/v1/events/vortex.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from dbtlabs.proto.public.v1.common import vortex_options_pb2 as dbtlabs_dot_proto_dot_public_dot_v1_dot_common_dot_vortex__options__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+dbtlabs/proto/public/v1/events/vortex.proto\x12\x10v1.events.vortex\x1a\x19google/protobuf/any.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x33\x64\x62tlabs/proto/public/v1/common/vortex_options.proto\"\xab\x02\n\rVortexMessage\x12!\n\x03\x61ny\x18\x01 \x01(\x0b\x32\x14.google.protobuf.Any\x12;\n\x17vortex_event_created_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x39\n\x15vortex_client_sent_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12>\n\x1avortex_backend_received_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12?\n\x1bvortex_backend_processed_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"Z\n\x12VortexMessageBatch\x12\x12\n\nrequest_id\x18\x01 \x01(\t\x12\x30\n\x07payload\x18\x02 \x03(\x0b\x32\x1f.v1.events.vortex.VortexMessage\"i\n\x17VortexDeadLetterMessage\x12\x10\n\x08type_url\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\x12\x13\n\x0bvalue_bytes\x18\x03 \x01(\x0c\x12\x0e\n\x06reason\x18\x04 \x01(\t:\x08\xd8\xa6\x1d\x04\x80\xa7\x1d\x01\"\xc6\x01\n\x17VortexMessageEnrichment\x12\x33\n\tclient_ip\x18\x01 \x01(\x0b\x32 .v1.events.vortex.VortexClientIp\x12?\n\x0f\x63lient_platform\x18\x02 \x01(\x0b\x32&.v1.events.vortex.VortexClientPlatform\x12\x35\n\nuser_agent\x18\x03 \x01(\x0b\x32!.v1.events.vortex.VortexUserAgent\"]\n\x0eVortexClientIp\x12\n\n\x02ip\x18\x01 \x01(\t\x12\r\n\x05proxy\x18\x02 \x01(\x08\x12\x30\n\x03geo\x18\x03 \x01(\x0b\x32#.v1.events.vortex.VortexGeolocation\"|\n\x11VortexGeolocation\x12\x0f\n\x07\x63ountry\x18\x01 \x01(\t\x12\x0c\n\x04\x63ity\x18\x02 \x01(\t\x12\x10\n\x08latitude\x18\x03 \x01(\x01\x12\x11\n\tlongitude\x18\x04 \x01(\x01\x12\x10\n\x08timezone\x18\x05 \x01(\t\x12\x11\n\tcontinent\x18\x06 \x01(\t\"\xb3\x01\n\x14VortexClientPlatform\x12\x0b\n\x03raw\x18\x01 \x01(\t\x12\x0f\n\x07service\x18\x02 \x01(\t\x12\x17\n\x0fservice_version\x18\x03 \x01(\t\x12\x0e\n\x06\x63lient\x18\x04 \x01(\t\x12\x16\n\x0e\x63lient_version\x18\x05 \x01(\t\x12\x19\n\x11\x64\x62t_proto_library\x18\x06 \x01(\t\x12!\n\x19\x64\x62t_proto_library_version\x18\x07 \x01(\t\"\x8d\x01\n\x0fVortexUserAgent\x12\x0b\n\x03raw\x18\x01 \x01(\t\x12\x0f\n\x07\x62rowser\x18\x02 \x01(\t\x12\x17\n\x0f\x62rowser_version\x18\x03 \x01(\t\x12\n\n\x02os\x18\x04 \x01(\t\x12\x12\n\nos_version\x18\x05 \x01(\t\x12\x0e\n\x06\x64\x65vice\x18\x06 \x01(\t\x12\x13\n\x0b\x64\x65vice_type\x18\x07 \x01(\tB3Z1github.com/dbt-labs/proto-golang/v1/events/vortexb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dbtlabs.proto.public.v1.events.vortex_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z1github.com/dbt-labs/proto-golang/v1/events/vortex'
  _globals['_VORTEXDEADLETTERMESSAGE']._loaded_options = None
  _globals['_VORTEXDEADLETTERMESSAGE']._serialized_options = b'\330\246\035\004\200\247\035\001'
  _globals['_VORTEXMESSAGE']._serialized_start=179
  _globals['_VORTEXMESSAGE']._serialized_end=478
  _globals['_VORTEXMESSAGEBATCH']._serialized_start=480
  _globals['_VORTEXMESSAGEBATCH']._serialized_end=570
  _globals['_VORTEXDEADLETTERMESSAGE']._serialized_start=572
  _globals['_VORTEXDEADLETTERMESSAGE']._serialized_end=677
  _globals['_VORTEXMESSAGEENRICHMENT']._serialized_start=680
  _globals['_VORTEXMESSAGEENRICHMENT']._serialized_end=878
  _globals['_VORTEXCLIENTIP']._serialized_start=880
  _globals['_VORTEXCLIENTIP']._serialized_end=973
  _globals['_VORTEXGEOLOCATION']._serialized_start=975
  _globals['_VORTEXGEOLOCATION']._serialized_end=1099
  _globals['_VORTEXCLIENTPLATFORM']._serialized_start=1102
  _globals['_VORTEXCLIENTPLATFORM']._serialized_end=1281
  _globals['_VORTEXUSERAGENT']._serialized_start=1284
  _globals['_VORTEXUSERAGENT']._serialized_end=1425
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class DebugValue(google.protobuf.message.Message):
    """General debug value holder for developer spans."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FLOAT64_FIELD_NUMBER: builtins.int
    BOOL_FIELD_NUMBER: builtins.int
    STRING_FIELD_NUMBER: builtins.int
    BYTES_FIELD_NUMBER: builtins.int
    float64: builtins.float
    bool: builtins.bool
    string: builtins.str
    bytes: builtins.bytes
    def __init__(
        self,
        *,
        float64: builtins.float = ...,
        bool: builtins.bool = ...,
        string: builtins.str = ...,
        bytes: builtins.bytes = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["bool", b"bool", "bytes", b"bytes", "float64", b"float64", "string", b"string", "value", b"value"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["bool", b"bool", "bytes", b"bytes", "float64", b"float64", "string", b"string", "value", b"value"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["value", b"value"]) -> typing.Literal["float64", "bool", "string", "bytes"] | None: ...

Global___DebugValue: typing_extensions.TypeAlias = DebugValue

@typing.final
class CallTrace(google.protobuf.message.Message):
    """Special event emitted only at TRACE level, and disabled by default.
    Used for troubleshooting complex bugs in Fusion itself.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class ExtraEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> Global___DebugValue: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: Global___DebugValue | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    NAME_FIELD_NUMBER: builtins.int
    FILE_FIELD_NUMBER: builtins.int
    LINE_FIELD_NUMBER: builtins.int
    EXTRA_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Internal developer span name, often a function/method."""
    file: builtins.str
    """File name where the span was created."""
    line: builtins.int
    """Line number in the file where the span was created."""
    @property
    def extra(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, Global___DebugValue]:
        """Arbitrary extra structured data."""

    def __init__(
        self,
        *,
        name: builtins.str = ...,
        file: builtins.str | None = ...,
        line: builtins.int | None = ...,
        extra: collections.abc.Mapping[builtins.str, Global___DebugValue] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["_file", b"_file", "_line", b"_line", "file", b"file", "line", b"line"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["_file", b"_file", "_line", b"_line", "extra", b"extra", "file", b"file", "line", b"line", "name", b"name"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_file", b"_file"]) -> typing.Literal["file"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_line", b"_line"]) -> typing.Literal["line"] | None: ...

Global___CallTrace: typing_extensions.TypeAlias = CallTrace

@typing.final
class Unknown(google.protobuf.message.Message):
    """Unknown span placeholder used as a fallback. Presence of this
    event in the stream indicates a bug in the telemetry instrumentation.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    FILE_FIELD_NUMBER: builtins.int
    LINE_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Inferred name, often a function/method."""
    file: builtins.str
    """File name where the span was created."""
    line: builtins.int
    """Line number in the file where the span was created."""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        file: builtins.str = ...,
        line: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["file", b"file", "line", b"line", "name", b"name"]) -> None: ...

Global___Unknown: typing_extensions.TypeAlias = Unknown



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _ArtifactType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ArtifactTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ArtifactType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    ARTIFACT_TYPE_UNSPECIFIED: _ArtifactType.ValueType  # 0
    ARTIFACT_TYPE_MANIFEST: _ArtifactType.ValueType  # 1
    ARTIFACT_TYPE_SEMANTIC_MANIFEST: _ArtifactType.ValueType  # 2
    ARTIFACT_TYPE_CATALOG: _ArtifactType.ValueType  # 3

class ArtifactType(_ArtifactType, metaclass=_ArtifactTypeEnumTypeWrapper):
    """Known artifact types written by dbt"""

ARTIFACT_TYPE_UNSPECIFIED: ArtifactType.ValueType  # 0
ARTIFACT_TYPE_MANIFEST: ArtifactType.ValueType  # 1
ARTIFACT_TYPE_SEMANTIC_MANIFEST: ArtifactType.ValueType  # 2
ARTIFACT_TYPE_CATALOG: ArtifactType.ValueType  # 3
Global___ArtifactType: typing_extensions.TypeAlias = ArtifactType

@typing.final
class ArtifactWritten(google.protobuf.message.Message):
    """Event emitted when an artifact is written to disk."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RELATIVE_PATH_FIELD_NUMBER: builtins.int
    ARTIFACT_TYPE_FIELD_NUMBER: builtins.int
    relative_path: builtins.str
    """The path to the artifact relative to the project root."""
    artifact_type: Global___ArtifactType.ValueType
    """Type of the artifact written."""
    def __init__(
        self,
        *,
        relative_path: builtins.str = ...,
        artifact_type: Global___ArtifactType.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["artifact_type", b"artifact_type", "relative_path", b"relative_path"]) -> None: ...

Global___ArtifactWritten: typing_extensions.TypeAlias = ArtifactWritten



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import dbtlabs.proto.public.v1.events.fusion.process.process_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class InvocationMetrics(google.protobuf.message.Message):
    """Aggregate invocation metrics."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class NodeTypeCountsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.int
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.int = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing.final
    class StatusCountsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.int
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.int = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    TOTAL_ERRORS_FIELD_NUMBER: builtins.int
    TOTAL_WARNINGS_FIELD_NUMBER: builtins.int
    AUTOFIX_SUGGESTIONS_FIELD_NUMBER: builtins.int
    NODE_TYPE_COUNTS_FIELD_NUMBER: builtins.int
    STATUS_COUNTS_FIELD_NUMBER: builtins.int
    total_errors: builtins.int
    total_warnings: builtins.int
    autofix_suggestions: builtins.int
    @property
    def node_type_counts(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.int]:
        """Counts of nodes processed by node type (e.g., "model", "test", "seed").
        Key is the lowercase node type name.
        """

    @property
    def status_counts(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.int]:
        """Counts of node outcomes by status category.
        Keys are: "success", "warn", "error", "reused", "skipped", "canceled", "no_op".
        Only non-zero counts are included.
        """

    def __init__(
        self,
        *,
        total_errors: builtins.int | None = ...,
        total_warnings: builtins.int | None = ...,
        autofix_suggestions: builtins.int | None = ...,
        node_type_counts: collections.abc.Mapping[builtins.str, builtins.int] | None = ...,
        status_counts: collections.abc.Mapping[builtins.str, builtins.int] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["_autofix_suggestions", b"_autofix_suggestions", "_total_errors", b"_total_errors", "_total_warnings", b"_total_warnings", "autofix_suggestions", b"autofix_suggestions", "total_errors", b"total_errors", "total_warnings", b"total_warnings"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["_autofix_suggestions", b"_autofix_suggestions", "_total_errors", b"_total_errors", "_total_warnings", b"_total_warnings", "autofix_suggestions", b"autofix_suggestions", "node_type_counts", b"node_type_counts", "status_counts", b"status_counts", "total_errors", b"total_errors", "total_warnings", b"total_warnings"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_autofix_suggestions", b"_autofix_suggestions"]) -> typing.Literal["autofix_suggestions"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_total_errors", b"_total_errors"]) -> typing.Literal["total_errors"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_total_warnings", b"_total_warnings"]) -> typing.Literal["total_warnings"] | None: ...

Global___InvocationMetrics: typing_extensions.TypeAlias = InvocationMetrics

@typing.final
class InvocationEvalArgs(google.protobuf.message.Message):
    """Structured evaluation arguments for the invocation."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMMAND_FIELD_NUMBER: builtins.int
    PROFILES_DIR_FIELD_NUMBER: builtins.int
    PACKAGES_INSTALL_PATH_FIELD_NUMBER: builtins.int
    TARGET_FIELD_NUMBER: builtins.int
    PROFILE_FIELD_NUMBER: builtins.int
    VARS_FIELD_NUMBER: builtins.int
    LIMIT_FIELD_NUMBER: builtins.int
    NUM_THREADS_FIELD_NUMBER: builtins.int
    SELECTOR_FIELD_NUMBER: builtins.int
    SELECT_FIELD_NUMBER: builtins.int
    EXCLUDE_FIELD_NUMBER: builtins.int
    INDIRECT_SELECTION_FIELD_NUMBER: builtins.int
    OUTPUT_KEYS_FIELD_NUMBER: builtins.int
    RESOURCE_TYPES_FIELD_NUMBER: builtins.int
    EXCLUDE_RESOURCE_TYPES_FIELD_NUMBER: builtins.int
    DEBUG_FIELD_NUMBER: builtins.int
    LOG_FORMAT_FIELD_NUMBER: builtins.int
    LOG_LEVEL_FIELD_NUMBER: builtins.int
    LOG_PATH_FIELD_NUMBER: builtins.int
    TARGET_PATH_FIELD_NUMBER: builtins.int
    PROJECT_DIR_FIELD_NUMBER: builtins.int
    QUIET_FIELD_NUMBER: builtins.int
    WRITE_JSON_FIELD_NUMBER: builtins.int
    WRITE_CATALOG_FIELD_NUMBER: builtins.int
    command: builtins.str
    """The dbt command executed, e.g. "run", "test", "build"."""
    profiles_dir: builtins.str
    """Common args

    The profile directory to load the profiles from
    """
    packages_install_path: builtins.str
    """The directory to install packages"""
    target: builtins.str
    """dbt target, e.g. "dev", "prod" """
    profile: builtins.str
    """Profile name used for the invocation"""
    vars: builtins.str
    """Vars to pass to the jinja environment. JSON blob string."""
    limit: builtins.int
    """Limiting number of shown rows. None means no limit; --limit -1 to remove limit"""
    num_threads: builtins.int
    """The number of threads to use"""
    selector: builtins.str
    """yaml selector"""
    indirect_selection: builtins.str
    """Indirect selection mode"""
    debug: builtins.bool
    """Debug flag"""
    log_format: builtins.str
    """Logging format"""
    log_level: builtins.str
    """Minimum severity for console/log file"""
    log_path: builtins.str
    """'log-path' for the current run, overriding 'DBT_LOG_PATH'."""
    target_path: builtins.str
    """The output directory for all produced assets"""
    project_dir: builtins.str
    """The directory to load the dbt project from"""
    quiet: builtins.bool
    """Suppress all non-error logging to stdout"""
    write_json: builtins.bool
    """Write JSON artifacts to disk"""
    write_catalog: builtins.bool
    """Write a catalog.json file to the target directory"""
    @property
    def select(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Select nodes to operate on"""

    @property
    def exclude(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Select nodes to exclude from selected nodes"""

    @property
    def output_keys(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Show output keys"""

    @property
    def resource_types(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Resource types to filter by"""

    @property
    def exclude_resource_types(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Exclude nodes of a specific type"""

    def __init__(
        self,
        *,
        command: builtins.str = ...,
        profiles_dir: builtins.str | None = ...,
        packages_install_path: builtins.str | None = ...,
        target: builtins.str | None = ...,
        profile: builtins.str | None = ...,
        vars: builtins.str = ...,
        limit: builtins.int | None = ...,
        num_threads: builtins.int | None = ...,
        selector: builtins.str | None = ...,
        select: collections.abc.Iterable[builtins.str] | None = ...,
        exclude: collections.abc.Iterable[builtins.str] | None = ...,
        indirect_selection: builtins.str | None = ...,
        output_keys: collections.abc.Iterable[builtins.str] | None = ...,
        resource_types: collections.abc.Iterable[builtins.str] | None = ...,
        exclude_resource_types: collections.abc.Iterable[builtins.str] | None = ...,
        debug: builtins.bool | None = ...,
        log_format: builtins.str | None = ...,
        log_level: builtins.str | None = ...,
        log_path: builtins.str | None = ...,
        target_path: builtins.str | None = ...,
        project_dir: builtins.str | None = ...,
        quiet: builtins.bool | None = ...,
        write_json: builtins.bool | None = ...,
        write_catalog: builtins.bool | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["_debug", b"_debug", "_indirect_selection", b"_indirect_selection", "_limit", b"_limit", "_log_format", b"_log_format", "_log_level", b"_log_level", "_log_path", b"_log_path", "_num_threads", b"_num_threads", "_packages_install_path", b"_packages_install_path", "_profile", b"_profile", "_profiles_dir", b"_profiles_dir", "_project_dir", b"_project_dir", "_quiet", b"_quiet", "_selector", b"_selector", "_target", b"_target", "_target_path", b"_target_path", "_write_catalog", b"_write_catalog", "_write_json", b"_write_json", "debug", b"debug", "indirect_selection", b"indirect_selection", "limit", b"limit", "log_format", b"log_format", "log_level", b"log_level", "log_path", b"log_path", "num_threads", b"num_threads", "packages_install_path", b"packages_install_path", "profile", b"profile", "profiles_dir", b"profiles_dir", "project_dir", b"project_dir", "quiet", b"quiet", "selector", b"selector", "target", b"target", "target_path", b"target_path", "write_catalog", b"write_catalog", "write_json", b"write_json"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["_debug", b"_debug", "_indirect_selection", b"_indirect_selection", "_limit", b"_limit", "_log_format", b"_log_format", "_log_level", b"_log_level", "_log_path", b"_log_path", "_num_threads", b"_num_threads", "_packages_install_path", b"_packages_install_path", "_profile", b"_profile", "_profiles_dir", b"_profiles_dir", "_project_dir", b"_project_dir", "_quiet", b"_quiet", "_selector", b"_selector", "_target", b"_target", "_target_path", b"_target_path", "_write_catalog", b"_write_catalog", "_write_json", b"_write_json", "command", b"command", "debug", b"debug", "exclude", b"exclude", "exclude_resource_types", b"exclude_resource_types", "indirect_selection", b"indirect_selection", "limit", b"limit", "log_format", b"log_format", "log_level", b"log_level", "log_path", b"log_path", "num_threads", b"num_threads", "output_keys", b"output_keys", "packages_install_path", b"packages_install_path", "profile", b"profile", "profiles_dir", b"profiles_dir", "project_dir", b"project_dir", "quiet", b"quiet", "resource_types", b"resource_types", "select", b"select", "selector", b"selector", "target", b"target", "target_path", b"target_path", "vars", b"vars", "write_catalog", b"write_catalog", "write_json", b"write_json"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_debug", b"_debug"]) -> typing.Literal["debug"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_indirect_selection", b"_indirect_selection"]) -> typing.Literal["indirect_selection"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_limit", b"_limit"]) -> typing.Literal["limit"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_log_format", b"_log_format"]) -> typing.Literal["log_format"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_log_level", b"_log_level"]) -> typing.Literal["log_level"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_log_path", b"_log_path"]) -> typing.Literal["log_path"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_num_threads", b"_num_threads"]) -> typing.Literal["num_threads"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_packages_install_path", b"_packages_install_path"]) -> typing.Literal["packages_install_path"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_profile", b"_profile"]) -> typing.Literal["profile"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_profiles_dir", b"_profiles_dir"]) -> typing.Literal["profiles_dir"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_project_dir", b"_project_dir"]) -> typing.Literal["project_dir"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_quiet", b"_quiet"]) -> typing.Literal["quiet"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_selector", b"_selector"]) -> typing.Literal["selector"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_target", b"_target"]) -> typing.Literal["target"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_target_path", b"_target_path"]) -> typing.Literal["target_path"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_write_catalog", b"_write_catalog"]) -> typing.Literal["write_catalog"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_write_json", b"_write_json"]) -> typing.Literal["write_json"] | None: ...

Global___InvocationEvalArgs: typing_extensions.TypeAlias = InvocationEvalArgs

@typing.final
class Invocation(google.protobuf.message.Message):
    """Invocation event holding identifying info and flattened attributes."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INVOCATION_ID_FIELD_NUMBER: builtins.int
    RAW_COMMAND_FIELD_NUMBER: builtins.int
    EVAL_ARGS_FIELD_NUMBER: builtins.int
    PROCESS_INFO_FIELD_NUMBER: builtins.int
    METRICS_FIELD_NUMBER: builtins.int
    PARENT_SPAN_ID_FIELD_NUMBER: builtins.int
    invocation_id: builtins.str
    """UUID string for the invocation id, either as passed in via args or generated (UUIDv7 in that case).
    Note, that `trace_id` is the same value stored as bytes and generally preferred
    for correlation with other events as it is present on all telemetry records.
    """
    raw_command: builtins.str
    """Raw command string as executed."""
    parent_span_id: builtins.int
    """Optional parent span ID for trace correlation.
    This allows linking this invocation to an external trace.
    """
    @property
    def eval_args(self) -> Global___InvocationEvalArgs:
        """Structured evaluation arguments."""

    @property
    def process_info(self) -> dbtlabs.proto.public.v1.events.fusion.process.process_pb2.Process:
        """Process-wide attributes."""

    @property
    def metrics(self) -> Global___InvocationMetrics:
        """Aggregate invocation metrics."""

    def __init__(
        self,
        *,
        invocation_id: builtins.str = ...,
        raw_command: builtins.str = ...,
        eval_args: Global___InvocationEvalArgs | None = ...,
        process_info: dbtlabs.proto.public.v1.events.fusion.process.process_pb2.Process | None = ...,
        metrics: Global___InvocationMetrics | None = ...,
        parent_span_id: builtins.int | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["_parent_span_id", b"_parent_span_id", "eval_args", b"eval_args", "metrics", b"metrics", "parent_span_id", b"parent_span_id", "process_info", b"process_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["_parent_span_id", b"_parent_span_id", "eval_args", b"eval_args", "invocation_id", b"invocation_id", "metrics", b"metrics", "parent_span_id", b"parent_span_id", "process_info", b"process_info", "raw_command", b"raw_command"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["_parent_span_id", b"_parent_span_id"]) -> typing.Literal["parent_span_id"] | None: ...

Global___Invocation: typing_extensions.TypeAlias = Invocation



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dbtlabs/proto/public/v1/events/fusion/log/log.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from dbtlabs.proto.public.v1.events.fusion.compat import otlp_pb2 as dbtlabs_dot_proto_dot_public_dot_v1_dot_events_dot_fusion_dot_compat_dot_otlp__pb2
from dbtlabs.proto.public.v1.events.fusion.phase import phase_pb2 as dbtlabs_dot_proto_dot_public_dot_v1_dot_events_dot_fusion_dot_phase_dot_phase__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3dbtlabs/proto/public/v1/events/fusion/log/log.proto\x12\x1bv1.public.events.fusion.log\x1a\x37\x64\x62tlabs/proto/public/v1/events/fusion/compat/otlp.proto\x1a\x37\x64\x62tlabs/proto/public/v1/events/fusion/phase/phase.proto\"\xab\x03\n\nLogMessage\x12\x11\n\x04\x63ode\x18\x01 \x01(\rH\x00\x88\x01\x01\x12 \n\x13\x64\x62t_core_event_code\x18\x02 \x01(\tH\x01\x88\x01\x01\x12P\n\x18original_severity_number\x18\x03 \x01(\x0e\x32..v1.public.events.fusion.compat.SeverityNumber\x12\x1e\n\x16original_severity_text\x18\x04 \x01(\t\x12\x16\n\tunique_id\x18\x05 \x01(\tH\x02\x88\x01\x01\x12\x11\n\x04\x66ile\x18\x06 \x01(\tH\x03\x88\x01\x01\x12\x11\n\x04line\x18\x07 \x01(\rH\x04\x88\x01\x01\x12\x41\n\x05phase\x18\x08 \x01(\x0e\x32-.v1.public.events.fusion.phase.ExecutionPhaseH\x05\x88\x01\x01\x12\x19\n\x0cpackage_name\x18\t \x01(\tH\x06\x88\x01\x01\x42\x07\n\x05_codeB\x16\n\x14_dbt_core_event_codeB\x0c\n\n_unique_idB\x07\n\x05_fileB\x07\n\x05_lineB\x08\n\x06_phaseB\x0f\n\r_package_name\"\xc8\x02\n\x0eUserLogMessage\x12\x10\n\x08is_print\x18\x01 \x01(\x08\x12\x1b\n\x13\x64\x62t_core_event_code\x18\x02 \x01(\t\x12\x16\n\tunique_id\x18\x03 \x01(\tH\x00\x88\x01\x01\x12\x41\n\x05phase\x18\x04 \x01(\x0e\x32-.v1.public.events.fusion.phase.ExecutionPhaseH\x01\x88\x01\x01\x12\x19\n\x0cpackage_name\x18\x05 \x01(\tH\x02\x88\x01\x01\x12\x11\n\x04line\x18\x06 \x01(\rH\x03\x88\x01\x01\x12\x13\n\x06\x63olumn\x18\x07 \x01(\rH\x04\x88\x01\x01\x12\x1a\n\rrelative_path\x18\x08 \x01(\tH\x05\x88\x01\x01\x42\x0c\n\n_unique_idB\x08\n\x06_phaseB\x0f\n\r_package_nameB\x07\n\x05_lineB\t\n\x07_columnB\x10\n\x0e_relative_path\"\xc0\x02\n\x0fProgressMessage\x12 \n\x13\x64\x62t_core_event_code\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x0e\n\x06\x61\x63tion\x18\x02 \x01(\t\x12\x0e\n\x06target\x18\x03 \x01(\t\x12\x18\n\x0b\x64\x65scription\x18\x04 \x01(\tH\x01\x88\x01\x01\x12\x16\n\tunique_id\x18\x05 \x01(\tH\x02\x88\x01\x01\x12\x11\n\x04\x66ile\x18\x06 \x01(\tH\x03\x88\x01\x01\x12\x11\n\x04line\x18\x07 \x01(\rH\x04\x88\x01\x01\x12\x41\n\x05phase\x18\x08 \x01(\x0e\x32-.v1.public.events.fusion.phase.ExecutionPhaseH\x05\x88\x01\x01\x42\x16\n\x14_dbt_core_event_codeB\x0e\n\x0c_descriptionB\x0c\n\n_unique_idB\x07\n\x05_fileB\x07\n\x05_lineB\x08\n\x06_phaseB>Z<github.com/dbt-labs/proto-golang/v1/public/events/fusion/logb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dbtlabs.proto.public.v1.events.fusion.log.log_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z<github.com/dbt-labs/proto-golang/v1/public/events/fusion/log'
  _globals['_LOGMESSAGE']._serialized_start=199
  _globals['_LOGMESSAGE']._serialized_end=626
  _globals['_USERLOGMESSAGE']._serialized_start=629
  _globals['_USERLOGMESSAGE']._serialized_end=957
  _globals['_PROGRESSMESSAGE']._serialized_start=960
  _globals['_PROGRESSMESSAGE']._serialized_end=1280
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _PackageType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _PackageTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_PackageType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    PACKAGE_TYPE_UNSPECIFIED: _PackageType.ValueType  # 0
    PACKAGE_TYPE_HUB: _PackageType.ValueType  # 1
    PACKAGE_TYPE_GIT: _PackageType.ValueType  # 2
    PACKAGE_TYPE_LOCAL: _PackageType.ValueType  # 3
    PACKAGE_TYPE_PRIVATE: _PackageType.ValueType  # 4
    PACKAGE_TYPE_TARBALL: _PackageType.ValueType  # 5

class PackageType(_PackageType, metaclass=_PackageTypeEnumTypeWrapper):
    """Type of package source"""

PACKAGE_TYPE_UNSPECIFIED: PackageType.ValueType  # 0
PACKAGE_TYPE_HUB: PackageType.ValueType  # 1
PACKAGE_TYPE_GIT: PackageType.ValueType  # 2
PACKAGE_TYPE_LOCAL: PackageType.ValueType  # 3
PACKAGE_TYPE_PRIVATE: PackageType.ValueType  # 4
PACKAGE_TYPE_TARBALL: PackageType.ValueType  # 5
Global___PackageType: typing_extensions.TypeAlias = PackageType

@typing.final
class DepsAddPackage(google.protobuf.message.Message):
    """Span emitted for each individual `deps add` call.
    This corresponds to dbt-core's `DepsAddPackage` (M032) event.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PACKAGE_NAME_FIELD_NUMBER: builtins.int
    PACKAGE_TYPE_FIELD_NUMBER: builtins.int
    PACKAGE_VERSION_FIELD_NUMBER: builtins.int
    DBT_CORE_EVENT_CODE_FIELD_NUMBER: builtins.int
    package_name: builtins.str
    """The name of the package that was installed"""
    package_type: Global___PackageType.ValueType
    """The type of the package source"""
    package_version: builtins.str
    """Optional version of the package (for hub packages, this is semantic version; for git/private, this is commit SHA)"""
    dbt_core_event_code: builtins.str
    """Legacy dbt core event code for backward compatibility (always "M032")"""
    def __init__(
        self,
        *,
        package_name: builtins.str = ...,
        package_type: Global___PackageType.ValueType = ...,
        package_version: builtins.str | None = ...,
        dbt_core_event_code: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["_package_version", b"_package_version", "package_version", b"package_version"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["_package_version", b"_package_version", "dbt_core_event_code", b"dbt_core_event_code", "package_name", b"package_name", "package_type", b"package_type", "package_version", b"package_version"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["_package_version", b"_package_version"]) -> typing.Literal["package_version"] | None: ...

Global___DepsAddPackage: typing_extensions.TypeAlias = DepsAddPackage

@typing.final
class DepsPackageInstalled(google.protobuf.message.Message):
    """Span emitted for each individual package installation during the deps command.
    This corresponds to dbt-core's `DepsStartPackageInstall` (M014) &
    `DepsInstallInfo` (M015) event for span start and end respectively.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PACKAGE_NAME_FIELD_NUMBER: builtins.int
    PACKAGE_TYPE_FIELD_NUMBER: builtins.int
    PACKAGE_VERSION_FIELD_NUMBER: builtins.int
    PACKAGE_URL_OR_PATH_FIELD_NUMBER: builtins.int
    DBT_CORE_EVENT_CODE_FIELD_NUMBER: builtins.int
    package_name: builtins.str
    """The name of the package that was installed. The name may not be known at span start."""
    package_type: Global___PackageType.ValueType
    """The type of the package source"""
    package_version: builtins.str
    """Optional version of the package (for hub packages, this is semantic version; for git/private, this is commit SHA)"""
    package_url_or_path: builtins.str
    """Optional scrubbed URL or path (for git, local, tarball packages)"""
    dbt_core_event_code: builtins.str
    """Legacy dbt core event code for backward compatibility ("M014" for start, "M015" for end)"""
    def __init__(
        self,
        *,
        package_name: builtins.str | None = ...,
        package_type: Global___PackageType.ValueType = ...,
        package_version: builtins.str | None = ...,
        package_url_or_path: builtins.str | None = ...,
        dbt_core_event_code: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["_package_name", b"_package_name", "_package_url_or_path", b"_package_url_or_path", "_package_version", b"_package_version", "package_name", b"package_name", "package_url_or_path", b"package_url_or_path", "package_version", b"package_version"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["_package_name", b"_package_name", "_package_url_or_path", b"_package_url_or_path", "_package_version", b"_package_version", "dbt_core_event_code", b"dbt_core_event_code", "package_name", b"package_name", "package_type", b"package_type", "package_url_or_path", b"package_url_or_path", "package_version", b"package_version"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_package_name", b"_package_name"]) -> typing.Literal["package_name"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_package_url_or_path", b"_package_url_or_path"]) -> typing.Literal["package_url_or_path"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_package_version", b"_package_version"]) -> typing.Literal["package_version"] | None: ...

Global___DepsPackageInstalled: typing_extensions.TypeAlias = DepsPackageInstalled

@typing.final
class DepsAllPackagesInstalled(google.protobuf.message.Message):
    """Span emitted for the entire project dependencies installation process.
    This is the parent span that encompasses all individual `DepsPackageInstalled` spans.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PACKAGE_COUNT_FIELD_NUMBER: builtins.int
    package_count: builtins.int
    """Total number of packages to be installed"""
    def __init__(
        self,
        *,
        package_count: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["package_count", b"package_count"]) -> None: ...

Global___DepsAllPackagesInstalled: typing_extensions.TypeAlias = DepsAllPackagesInstalled



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dbtlabs/proto/public/v1/events/fusion/query/query.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from dbtlabs.proto.public.v1.events.fusion.phase import phase_pb2 as dbtlabs_dot_proto_dot_public_dot_v1_dot_events_dot_fusion_dot_phase_dot_phase__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7dbtlabs/proto/public/v1/events/fusion/query/query.proto\x12\x1dv1.public.events.fusion.query\x1a\x37\x64\x62tlabs/proto/public/v1/events/fusion/phase/phase.proto\"\xfe\x03\n\rQueryExecuted\x12\x0b\n\x03sql\x18\x01 \x01(\t\x12\x10\n\x08sql_hash\x18\x02 \x01(\t\x12\x14\n\x0c\x61\x64\x61pter_type\x18\x03 \x01(\t\x12\x1e\n\x11query_description\x18\x04 \x01(\tH\x00\x88\x01\x01\x12\x15\n\x08query_id\x18\x05 \x01(\tH\x01\x88\x01\x01\x12\x16\n\tunique_id\x18\x06 \x01(\tH\x02\x88\x01\x01\x12\x42\n\rquery_outcome\x18\x07 \x01(\x0e\x32+.v1.public.events.fusion.query.QueryOutcome\x12\x41\n\x05phase\x18\x08 \x01(\x0e\x32-.v1.public.events.fusion.phase.ExecutionPhaseH\x03\x88\x01\x01\x12(\n\x1bquery_error_adapter_message\x18\t \x01(\tH\x04\x88\x01\x01\x12$\n\x17query_error_vendor_code\x18\n \x01(\x05H\x05\x88\x01\x01\x12\x1b\n\x13\x64\x62t_core_event_code\x18\x0b \x01(\tB\x14\n\x12_query_descriptionB\x0b\n\t_query_idB\x0c\n\n_unique_idB\x08\n\x06_phaseB\x1e\n\x1c_query_error_adapter_messageB\x1a\n\x18_query_error_vendor_code*}\n\x0cQueryOutcome\x12\x1d\n\x19QUERY_OUTCOME_UNSPECIFIED\x10\x00\x12\x19\n\x15QUERY_OUTCOME_SUCCESS\x10\x01\x12\x17\n\x13QUERY_OUTCOME_ERROR\x10\x02\x12\x1a\n\x16QUERY_OUTCOME_CANCELED\x10\x03\x42@Z>github.com/dbt-labs/proto-golang/v1/public/events/fusion/queryb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dbtlabs.proto.public.v1.events.fusion.query.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z>github.com/dbt-labs/proto-golang/v1/public/events/fusion/query'
  _globals['_QUERYOUTCOME']._serialized_start=660
  _globals['_QUERYOUTCOME']._serialized_end=785
  _globals['_QUERYEXECUTED']._serialized_start=148
  _globals['_QUERYEXECUTED']._serialized_end=658
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dbtlabs/proto/public/v1/events/vscode.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from dbtlabs.proto.public.v1.common import vortex_options_pb2 as dbtlabs_dot_proto_dot_public_dot_v1_dot_common_dot_vortex__options__pb2
from dbtlabs.proto.public.v1.events import vortex_pb2 as dbtlabs_dot_proto_dot_public_dot_v1_dot_events_dot_vortex__pb2
from dbtlabs.proto.public.v1.fields import vscode_types_pb2 as dbtlabs_dot_proto_dot_public_dot_v1_dot_fields_dot_vscode__types__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+dbtlabs/proto/public/v1/events/vscode.proto\x12\x15v1.public.events.vsce\x1a\x33\x64\x62tlabs/proto/public/v1/common/vortex_options.proto\x1a+dbtlabs/proto/public/v1/events/vortex.proto\x1a\x31\x64\x62tlabs/proto/public/v1/fields/vscode_types.proto\"\xe5\x03\n\x12\x45xtensionActivated\x12=\n\nenrichment\x18\x01 \x01(\x0b\x32).v1.events.vortex.VortexMessageEnrichment\x12\x35\n\x06\x65\x64itor\x18\x02 \x01(\x0b\x32%.v1.public.fields.vscode_types.Editor\x12\x31\n\x04user\x18\x03 \x01(\x0b\x32#.v1.public.fields.vscode_types.User\x12\x0f\n\x07os_name\x18\x04 \x01(\t\x12\x12\n\nos_version\x18\x05 \x01(\t\x12\x14\n\x0cinit_success\x18\x06 \x01(\x08\x12\x12\n\ninit_error\x18\x07 \x01(\t\x12\x19\n\x11init_error_detail\x18\x08 \x01(\t\x12\x18\n\x10init_duration_ms\x18\t \x01(\x03\x12\x18\n\x10is_lsp_installed\x18\n \x01(\x08\x12\x1b\n\x13is_fusion_installed\x18\x0b \x01(\x08\x12\x13\n\x0b\x64\x62t_version\x18\x0c \x01(\t\x12 \n\x18\x64\x62t_local_cookie_user_id\x18\r \x01(\t\x12\x14\n\x0cmodels_count\x18\x0e \x01(\x05\x12\x14\n\x0c\x61\x64\x61pter_type\x18\x0f \x01(\t:\x08\xd8\xa6\x1d\x03\x80\xa7\x1d\x01\"\xe3\x04\n\x13\x45xtensionLspCompile\x12=\n\nenrichment\x18\x01 \x01(\x0b\x32).v1.events.vortex.VortexMessageEnrichment\x12\x35\n\x06\x65\x64itor\x18\x02 \x01(\x0b\x32%.v1.public.fields.vscode_types.Editor\x12\x31\n\x04user\x18\x03 \x01(\x0b\x32#.v1.public.fields.vscode_types.User\x12\x12\n\nproject_id\x18\x04 \x01(\t\x12\x14\n\x0c\x61\x64\x61pter_type\x18\x05 \x01(\t\x12\x19\n\x11\x61\x64\x61pter_unique_id\x18\x06 \x01(\t\x12\x13\n\x0b\x64\x62t_version\x18\x07 \x01(\t\x12\x17\n\x0f\x63ompile_success\x18\x08 \x01(\x08\x12;\n\x06\x65rrors\x18\t \x03(\x0b\x32+.v1.public.fields.vscode_types.CompileError\x12\x13\n\x0b\x64uration_ms\x18\n \x01(\x03\x12@\n\x0c\x63ompile_type\x18\x0b \x01(\x0e\x32*.v1.public.fields.vscode_types.CompileType\x12\x14\n\x0cmodels_count\x18\x0c \x01(\x05\x12\x16\n\x0euser_initiated\x18\r \x01(\x08\x12\x42\n\rcompile_cause\x18\x0e \x01(\x0e\x32+.v1.public.fields.vscode_types.CompileCause\x12 \n\x18\x64\x62t_local_cookie_user_id\x18\x0f \x01(\t:\x08\xd8\xa6\x1d\x03\x80\xa7\x1d\x01\"\xb3\x02\n\x18\x45xtensionUserStateChange\x12=\n\nenrichment\x18\x01 \x01(\x0b\x32).v1.events.vortex.VortexMessageEnrichment\x12\x35\n\x06\x65\x64itor\x18\x02 \x01(\x0b\x32%.v1.public.fields.vscode_types.Editor\x12\x31\n\x04user\x18\x03 \x01(\x0b\x32#.v1.public.fields.vscode_types.User\x12\x42\n\x10\x63hanged_to_state\x18\x04 \x01(\x0e\x32(.v1.public.fields.vscode_types.UserState\x12 \n\x18\x64\x62t_local_cookie_user_id\x18\x05 \x01(\t:\x08\xd8\xa6\x1d\x03\x80\xa7\x1d\x01\"\xea\x01\n\x13\x45xtensionCtePreview\x12=\n\nenrichment\x18\x01 \x01(\x0b\x32).v1.events.vortex.VortexMessageEnrichment\x12\x35\n\x06\x65\x64itor\x18\x02 \x01(\x0b\x32%.v1.public.fields.vscode_types.Editor\x12\x31\n\x04user\x18\x03 \x01(\x0b\x32#.v1.public.fields.vscode_types.User\x12 \n\x18\x64\x62t_local_cookie_user_id\x18\x04 \x01(\t:\x08\xd8\xa6\x1d\x03\x80\xa7\x1d\x01\"\xf1\x01\n\x1a\x45xtensionLineageTabClicked\x12=\n\nenrichment\x18\x01 \x01(\x0b\x32).v1.events.vortex.VortexMessageEnrichment\x12\x35\n\x06\x65\x64itor\x18\x02 \x01(\x0b\x32%.v1.public.fields.vscode_types.Editor\x12\x31\n\x04user\x18\x03 \x01(\x0b\x32#.v1.public.fields.vscode_types.User\x12 \n\x18\x64\x62t_local_cookie_user_id\x18\x04 \x01(\t:\x08\xd8\xa6\x1d\x03\x80\xa7\x1d\x01\"\xed\x01\n\x16\x45xtensionColumnLineage\x12=\n\nenrichment\x18\x01 \x01(\x0b\x32).v1.events.vortex.VortexMessageEnrichment\x12\x35\n\x06\x65\x64itor\x18\x02 \x01(\x0b\x32%.v1.public.fields.vscode_types.Editor\x12\x31\n\x04user\x18\x03 \x01(\x0b\x32#.v1.public.fields.vscode_types.User\x12 \n\x18\x64\x62t_local_cookie_user_id\x18\x04 \x01(\t:\x08\xd8\xa6\x1d\x03\x80\xa7\x1d\x01\"\xf0\x01\n\x19\x45xtensionShowCompiledFile\x12=\n\nenrichment\x18\x01 \x01(\x0b\x32).v1.events.vortex.VortexMessageEnrichment\x12\x35\n\x06\x65\x64itor\x18\x02 \x01(\x0b\x32%.v1.public.fields.vscode_types.Editor\x12\x31\n\x04user\x18\x03 \x01(\x0b\x32#.v1.public.fields.vscode_types.User\x12 \n\x18\x64\x62t_local_cookie_user_id\x18\x04 \x01(\t:\x08\xd8\xa6\x1d\x03\x80\xa7\x1d\x01\"\xeb\x01\n\x14\x45xtensionModelRename\x12=\n\nenrichment\x18\x01 \x01(\x0b\x32).v1.events.vortex.VortexMessageEnrichment\x12\x35\n\x06\x65\x64itor\x18\x02 \x01(\x0b\x32%.v1.public.fields.vscode_types.Editor\x12\x31\n\x04user\x18\x03 \x01(\x0b\x32#.v1.public.fields.vscode_types.User\x12 \n\x18\x64\x62t_local_cookie_user_id\x18\x04 \x01(\t:\x08\xd8\xa6\x1d\x03\x80\xa7\x1d\x01\"\xec\x01\n\x15\x45xtensionColumnRename\x12=\n\nenrichment\x18\x01 \x01(\x0b\x32).v1.events.vortex.VortexMessageEnrichment\x12\x35\n\x06\x65\x64itor\x18\x02 \x01(\x0b\x32%.v1.public.fields.vscode_types.Editor\x12\x31\n\x04user\x18\x03 \x01(\x0b\x32#.v1.public.fields.vscode_types.User\x12 \n\x18\x64\x62t_local_cookie_user_id\x18\x04 \x01(\t:\x08\xd8\xa6\x1d\x03\x80\xa7\x1d\x01\"\x87\x02\n\x16\x45xtensionUsedBuildMenu\x12=\n\nenrichment\x18\x01 \x01(\x0b\x32).v1.events.vortex.VortexMessageEnrichment\x12\x35\n\x06\x65\x64itor\x18\x02 \x01(\x0b\x32%.v1.public.fields.vscode_types.Editor\x12\x31\n\x04user\x18\x03 \x01(\x0b\x32#.v1.public.fields.vscode_types.User\x12\x18\n\x10selected_command\x18\x04 \x01(\t\x12 \n\x18\x64\x62t_local_cookie_user_id\x18\x05 \x01(\t:\x08\xd8\xa6\x1d\x03\x80\xa7\x1d\x01\"\x8a\x02\n\x1d\x45xtensionGetSupportPopupShown\x12=\n\nenrichment\x18\x01 \x01(\x0b\x32).v1.events.vortex.VortexMessageEnrichment\x12\x35\n\x06\x65\x64itor\x18\x02 \x01(\x0b\x32%.v1.public.fields.vscode_types.Editor\x12\x31\n\x04user\x18\x03 \x01(\x0b\x32#.v1.public.fields.vscode_types.User\x12\x14\n\x0csupport_type\x18\x04 \x01(\t\x12 \n\x18\x64\x62t_local_cookie_user_id\x18\x05 \x01(\t:\x08\xd8\xa6\x1d\x03\x80\xa7\x1d\x01\"\x87\x02\n\x1a\x45xtensionGetSupportClicked\x12=\n\nenrichment\x18\x01 \x01(\x0b\x32).v1.events.vortex.VortexMessageEnrichment\x12\x35\n\x06\x65\x64itor\x18\x02 \x01(\x0b\x32%.v1.public.fields.vscode_types.Editor\x12\x31\n\x04user\x18\x03 \x01(\x0b\x32#.v1.public.fields.vscode_types.User\x12\x14\n\x0csupport_type\x18\x04 \x01(\t\x12 \n\x18\x64\x62t_local_cookie_user_id\x18\x05 \x01(\t:\x08\xd8\xa6\x1d\x03\x80\xa7\x1d\x01\"\x89\x02\n\x1c\x45xtensionGetSupportFormShown\x12=\n\nenrichment\x18\x01 \x01(\x0b\x32).v1.events.vortex.VortexMessageEnrichment\x12\x35\n\x06\x65\x64itor\x18\x02 \x01(\x0b\x32%.v1.public.fields.vscode_types.Editor\x12\x31\n\x04user\x18\x03 \x01(\x0b\x32#.v1.public.fields.vscode_types.User\x12\x14\n\x0csupport_type\x18\x04 \x01(\t\x12 \n\x18\x64\x62t_local_cookie_user_id\x18\x05 \x01(\t:\x08\xd8\xa6\x1d\x03\x80\xa7\x1d\x01\"\x95\x02\n(ExtensionGetSupportUnverifiedNoticeShown\x12=\n\nenrichment\x18\x01 \x01(\x0b\x32).v1.events.vortex.VortexMessageEnrichment\x12\x35\n\x06\x65\x64itor\x18\x02 \x01(\x0b\x32%.v1.public.fields.vscode_types.Editor\x12\x31\n\x04user\x18\x03 \x01(\x0b\x32#.v1.public.fields.vscode_types.User\x12\x14\n\x0csupport_type\x18\x04 \x01(\t\x12 \n\x18\x64\x62t_local_cookie_user_id\x18\x05 \x01(\t:\x08\xd8\xa6\x1d\x03\x80\xa7\x1d\x01\"\x9e\x02\n ExtensionGetSupportFormSubmitted\x12=\n\nenrichment\x18\x01 \x01(\x0b\x32).v1.events.vortex.VortexMessageEnrichment\x12\x35\n\x06\x65\x64itor\x18\x02 \x01(\x0b\x32%.v1.public.fields.vscode_types.Editor\x12\x31\n\x04user\x18\x03 \x01(\x0b\x32#.v1.public.fields.vscode_types.User\x12\x14\n\x0csupport_type\x18\x04 \x01(\t\x12\x0f\n\x07success\x18\x05 \x01(\x08\x12 \n\x18\x64\x62t_local_cookie_user_id\x18\x06 \x01(\t:\x08\xd8\xa6\x1d\x03\x80\xa7\x1d\x01\"\x8d\x02\n ExtensionGetSupportFormCancelled\x12=\n\nenrichment\x18\x01 \x01(\x0b\x32).v1.events.vortex.VortexMessageEnrichment\x12\x35\n\x06\x65\x64itor\x18\x02 \x01(\x0b\x32%.v1.public.fields.vscode_types.Editor\x12\x31\n\x04user\x18\x03 \x01(\x0b\x32#.v1.public.fields.vscode_types.User\x12\x14\n\x0csupport_type\x18\x04 \x01(\t\x12 \n\x18\x64\x62t_local_cookie_user_id\x18\x05 \x01(\t:\x08\xd8\xa6\x1d\x03\x80\xa7\x1d\x01\"\x8b\x02\n\x1e\x45xtensionGetSupportPanelClosed\x12=\n\nenrichment\x18\x01 \x01(\x0b\x32).v1.events.vortex.VortexMessageEnrichment\x12\x35\n\x06\x65\x64itor\x18\x02 \x01(\x0b\x32%.v1.public.fields.vscode_types.Editor\x12\x31\n\x04user\x18\x03 \x01(\x0b\x32#.v1.public.fields.vscode_types.User\x12\x14\n\x0csupport_type\x18\x04 \x01(\t\x12 \n\x18\x64\x62t_local_cookie_user_id\x18\x05 \x01(\t:\x08\xd8\xa6\x1d\x03\x80\xa7\x1d\x01\"\xff\x01\n\x16\x45xtensionCompareViewed\x12=\n\nenrichment\x18\x01 \x01(\x0b\x32).v1.events.vortex.VortexMessageEnrichment\x12\x35\n\x06\x65\x64itor\x18\x02 \x01(\x0b\x32%.v1.public.fields.vscode_types.Editor\x12\x31\n\x04user\x18\x03 \x01(\x0b\x32#.v1.public.fields.vscode_types.User\x12 \n\x18\x64\x62t_local_cookie_user_id\x18\x04 \x01(\t\x12\x10\n\x08\x65vent_id\x18\x05 \x01(\t:\x08\xd8\xa6\x1d\x03\x80\xa7\x1d\x01\"\x94\x02\n\x17\x45xtensionCompareStarted\x12=\n\nenrichment\x18\x01 \x01(\x0b\x32).v1.events.vortex.VortexMessageEnrichment\x12\x35\n\x06\x65\x64itor\x18\x02 \x01(\x0b\x32%.v1.public.fields.vscode_types.Editor\x12\x31\n\x04user\x18\x03 \x01(\x0b\x32#.v1.public.fields.vscode_types.User\x12\x12\n\ncompare_id\x18\x04 \x01(\t\x12 \n\x18\x64\x62t_local_cookie_user_id\x18\x05 \x01(\t\x12\x10\n\x08\x65vent_id\x18\x06 \x01(\t:\x08\xd8\xa6\x1d\x03\x80\xa7\x1d\x01\"\xdb\x02\n\x18\x45xtensionCompareFinished\x12=\n\nenrichment\x18\x01 \x01(\x0b\x32).v1.events.vortex.VortexMessageEnrichment\x12\x35\n\x06\x65\x64itor\x18\x02 \x01(\x0b\x32%.v1.public.fields.vscode_types.Editor\x12\x31\n\x04user\x18\x03 \x01(\x0b\x32#.v1.public.fields.vscode_types.User\x12\x12\n\ncompare_id\x18\x04 \x01(\t\x12\x13\n\x0b\x64uration_ms\x18\x05 \x01(\x03\x12\x17\n\x0f\x63ompare_success\x18\x06 \x01(\x08\x12\x16\n\x0e\x66\x61ilure_reason\x18\x07 \x01(\t\x12 \n\x18\x64\x62t_local_cookie_user_id\x18\x08 \x01(\t\x12\x10\n\x08\x65vent_id\x18\t \x01(\t:\x08\xd8\xa6\x1d\x03\x80\xa7\x1d\x01\"\x8e\x02\n%ExtensionRegistrationMessageDismissed\x12=\n\nenrichment\x18\x01 \x01(\x0b\x32).v1.events.vortex.VortexMessageEnrichment\x12\x35\n\x06\x65\x64itor\x18\x02 \x01(\x0b\x32%.v1.public.fields.vscode_types.Editor\x12\x31\n\x04user\x18\x03 \x01(\x0b\x32#.v1.public.fields.vscode_types.User\x12 \n\x18\x64\x62t_local_cookie_user_id\x18\x04 \x01(\t\x12\x10\n\x08\x65vent_id\x18\x05 \x01(\t:\x08\xd8\xa6\x1d\x03\x80\xa7\x1d\x01\"\xeb\x02\n\x18\x45xtensionRegisterStarted\x12=\n\nenrichment\x18\x01 \x01(\x0b\x32).v1.events.vortex.VortexMessageEnrichment\x12\x35\n\x06\x65\x64itor\x18\x02 \x01(\x0b\x32%.v1.public.fields.vscode_types.Editor\x12\x31\n\x04user\x18\x03 \x01(\x0b\x32#.v1.public.fields.vscode_types.User\x12 \n\x18\x64\x62t_local_cookie_user_id\x18\x04 \x01(\t\x12\x10\n\x08\x65vent_id\x18\x05 \x01(\t\x12P\n\x0etrigger_method\x18\x06 \x01(\x0e\x32\x38.v1.public.fields.vscode_types.RegistrationTriggerMethod\x12\x16\n\x0e\x63orrelation_id\x18\x07 \x01(\t:\x08\xd8\xa6\x1d\x03\x80\xa7\x1d\x01\"\xd5\x02\n!ExtensionRegistrationUrlAttempted\x12=\n\nenrichment\x18\x01 \x01(\x0b\x32).v1.events.vortex.VortexMessageEnrichment\x12\x35\n\x06\x65\x64itor\x18\x02 \x01(\x0b\x32%.v1.public.fields.vscode_types.Editor\x12\x31\n\x04user\x18\x03 \x01(\x0b\x32#.v1.public.fields.vscode_types.User\x12 \n\x18\x64\x62t_local_cookie_user_id\x18\x04 \x01(\t\x12\x10\n\x08\x65vent_id\x18\x05 \x01(\t\x12\x12\n\nurl_opened\x18\x06 \x01(\x08\x12\x1d\n\x15oauth_params_included\x18\x07 \x01(\x08\x12\x16\n\x0e\x63orrelation_id\x18\x08 \x01(\t:\x08\xd8\xa6\x1d\x03\x80\xa7\x1d\x01\"\xbf\x03\n\x1e\x45xtensionRegistrationCompleted\x12=\n\nenrichment\x18\x01 \x01(\x0b\x32).v1.events.vortex.VortexMessageEnrichment\x12\x35\n\x06\x65\x64itor\x18\x02 \x01(\x0b\x32%.v1.public.fields.vscode_types.Editor\x12\x31\n\x04user\x18\x03 \x01(\x0b\x32#.v1.public.fields.vscode_types.User\x12 \n\x18\x64\x62t_local_cookie_user_id\x18\x04 \x01(\t\x12\x10\n\x08\x65vent_id\x18\x05 \x01(\t\x12N\n\x13registration_method\x18\x06 \x01(\x0e\x32\x31.v1.public.fields.vscode_types.RegistrationMethod\x12\x13\n\x0b\x64uration_ms\x18\x07 \x01(\x03\x12\x16\n\x0e\x63orrelation_id\x18\x08 \x01(\t\x12\x12\n\naccount_id\x18\t \x01(\t\x12\x0f\n\x07user_id\x18\n \x01(\t\x12\x14\n\x0c\x61\x63\x63ount_host\x18\x0b \x01(\t:\x08\xd8\xa6\x1d\x03\x80\xa7\x1d\x01\"\x8d\x03\n\x1d\x45xtensionRegistrationTimedOut\x12=\n\nenrichment\x18\x01 \x01(\x0b\x32).v1.events.vortex.VortexMessageEnrichment\x12\x35\n\x06\x65\x64itor\x18\x02 \x01(\x0b\x32%.v1.public.fields.vscode_types.Editor\x12\x31\n\x04user\x18\x03 \x01(\x0b\x32#.v1.public.fields.vscode_types.User\x12 \n\x18\x64\x62t_local_cookie_user_id\x18\x04 \x01(\t\x12\x10\n\x08\x65vent_id\x18\x05 \x01(\t\x12P\n\x0etrigger_method\x18\x06 \x01(\x0e\x32\x38.v1.public.fields.vscode_types.RegistrationTriggerMethod\x12\x1b\n\x13timeout_duration_ms\x18\x07 \x01(\x03\x12\x16\n\x0e\x63orrelation_id\x18\x08 \x01(\t:\x08\xd8\xa6\x1d\x03\x80\xa7\x1d\x01\"\xad\x03\n\x1c\x45xtensionRegistrationErrored\x12=\n\nenrichment\x18\x01 \x01(\x0b\x32).v1.events.vortex.VortexMessageEnrichment\x12\x35\n\x06\x65\x64itor\x18\x02 \x01(\x0b\x32%.v1.public.fields.vscode_types.Editor\x12\x31\n\x04user\x18\x03 \x01(\x0b\x32#.v1.public.fields.vscode_types.User\x12 \n\x18\x64\x62t_local_cookie_user_id\x18\x04 \x01(\t\x12\x10\n\x08\x65vent_id\x18\x05 \x01(\t\x12N\n\x13registration_method\x18\x06 \x01(\x0e\x32\x31.v1.public.fields.vscode_types.RegistrationMethod\x12\x12\n\nerror_type\x18\x07 \x01(\t\x12\x15\n\rerror_message\x18\x08 \x01(\t\x12\x13\n\x0b\x64uration_ms\x18\t \x01(\x03\x12\x16\n\x0e\x63orrelation_id\x18\n \x01(\t:\x08\xd8\xa6\x1d\x03\x80\xa7\x1d\x01\x42\x38Z6github.com/dbt-labs/proto-golang/v1/public/events/vsceb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dbtlabs.proto.public.v1.events.vscode_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z6github.com/dbt-labs/proto-golang/v1/public/events/vsce'
  _globals['_EXTENSIONACTIVATED']._loaded_options = None
  _globals['_EXTENSIONACTIVATED']._serialized_options = b'\330\246\035\003\200\247\035\001'
  _globals['_EXTENSIONLSPCOMPILE']._loaded_options = None
  _globals['_EXTENSIONLSPCOMPILE']._serialized_options = b'\330\246\035\003\200\247\035\001'
  _globals['_EXTENSIONUSERSTATECHANGE']._loaded_options = None
  _globals['_EXTENSIONUSERSTATECHANGE']._serialized_options = b'\330\246\035\003\200\247\035\001'
  _globals['_EXTENSIONCTEPREVIEW']._loaded_options = None
  _globals['_EXTENSIONCTEPREVIEW']._serialized_options = b'\330\246\035\003\200\247\035\001'
  _globals['_EXTENSIONLINEAGETABCLICKED']._loaded_options = None
  _globals['_EXTENSIONLINEAGETABCLICKED']._serialized_options = b'\330\246\035\003\200\247\035\001'
  _globals['_EXTENSIONCOLUMNLINEAGE']._loaded_options = None
  _globals['_EXTENSIONCOLUMNLINEAGE']._serialized_options = b'\330\246\035\003\200\247\035\001'
  _globals['_EXTENSIONSHOWCOMPILEDFILE']._loaded_options = None
  _globals['_EXTENSIONSHOWCOMPILEDFILE']._serialized_options = b'\330\246\035\003\200\247\035\001'
  _globals['_EXTENSIONMODELRENAME']._loaded_options = None
  _globals['_EXTENSIONMODELRENAME']._serialized_options = b'\330\246\035\003\200\247\035\001'
  _globals['_EXTENSIONCOLUMNRENAME']._loaded_options = None
  _globals['_EXTENSIONCOLUMNRENAME']._serialized_options = b'\330\246\035\003\200\247\035\001'
  _globals['_EXTENSIONUSEDBUILDMENU']._loaded_options = None
  _globals['_EXTENSIONUSEDBUILDMENU']._serialized_options = b'\330\246\035\003\200\247\035\001'
  _globals['_EXTENSIONGETSUPPORTPOPUPSHOWN']._loaded_options = None
  _globals['_EXTENSIONGETSUPPORTPOPUPSHOWN']._serialized_options = b'\330\246\035\003\200\247\035\001'
  _globals['_EXTENSIONGETSUPPORTCLICKED']._loaded_options = None
  _globals['_EXTENSIONGETSUPPORTCLICKED']._serialized_options = b'\330\246\035\003\200\247\035\001'
  _globals['_EXTENSIONGETSUPPORTFORMSHOWN']._loaded_options = None
  _globals['_EXTENSIONGETSUPPORTFORMSHOWN']._serialized_options = b'\330\246\035\003\200\247\035\001'
  _globals['_EXTENSIONGETSUPPORTUNVERIFIEDNOTICESHOWN']._loaded_options = None
  _globals['_EXTENSIONGETSUPPORTUNVERIFIEDNOTICESHOWN']._serialized_options = b'\330\246\035\003\200\247\035\001'
  _globals['_EXTENSIONGETSUPPORTFORMSUBMITTED']._loaded_options = None
  _globals['_EXTENSIONGETSUPPORTFORMSUBMITTED']._serialized_options = b'\330\246\035\003\200\247\035\001'
  _globals['_EXTENSIONGETSUPPORTFORMCANCELLED']._loaded_options = None
  _globals['_EXTENSIONGETSUPPORTFORMCANCELLED']._serialized_options = b'\330\246\035\003\200\247\035\001'
  _globals['_EXTENSIONGETSUPPORTPANELCLOSED']._loaded_options = None
  _globals['_EXTENSIONGETSUPPORTPANELCLOSED']._serialized_options = b'\330\246\035\003\200\247\035\001'
  _globals['_EXTENSIONCOMPAREVIEWED']._loaded_options = None
  _globals['_EXTENSIONCOMPAREVIEWED']._serialized_options = b'\330\246\035\003\200\247\035\001'
  _globals['_EXTENSIONCOMPARESTARTED']._loaded_options = None
  _globals['_EXTENSIONCOMPARESTARTED']._serialized_options = b'\330\246\035\003\200\247\035\001'
  _globals['_EXTENSIONCOMPAREFINISHED']._loaded_options = None
  _globals['_EXTENSIONCOMPAREFINISHED']._serialized_options = b'\330\246\035\003\200\247\035\001'
  _globals['_EXTENSIONREGISTRATIONMESSAGEDISMISSED']._loaded_options = None
  _globals['_EXTENSIONREGISTRATIONMESSAGEDISMISSED']._serialized_options = b'\330\246\035\003\200\247\035\001'
  _globals['_EXTENSIONREGISTERSTARTED']._loaded_options = None
  _globals['_EXTENSIONREGISTERSTARTED']._serialized_options = b'\330\246\035\003\200\247\035\001'
  _globals['_EXTENSIONREGISTRATIONURLATTEMPTED']._loaded_options = None
  _globals['_EXTENSIONREGISTRATIONURLATTEMPTED']._serialized_options = b'\330\246\035\003\200\247\035\001'
  _globals['_EXTENSIONREGISTRATIONCOMPLETED']._loaded_options = None
  _globals['_EXTENSIONREGISTRATIONCOMPLETED']._serialized_options = b'\330\246\035\003\200\247\035\001'
  _globals['_EXTENSIONREGISTRATIONTIMEDOUT']._loaded_options = None
  _globals['_EXTENSIONREGISTRATIONTIMEDOUT']._serialized_options = b'\330\246\035\003\200\247\035\001'
  _globals['_EXTENSIONREGISTRATIONERRORED']._loaded_options = None
  _globals['_EXTENSIONREGISTRATIONERRORED']._serialized_options = b'\330\246\035\003\200\247\035\001'
  _globals['_EXTENSIONACTIVATED']._serialized_start=220
  _globals['_EXTENSIONACTIVATED']._serialized_end=705
  _globals['_EXTENSIONLSPCOMPILE']._serialized_start=708
  _globals['_EXTENSIONLSPCOMPILE']._serialized_end=1319
  _globals['_EXTENSIONUSERSTATECHANGE']._serialized_start=1322
  _globals['_EXTENSIONUSERSTATECHANGE']._serialized_end=1629
  _globals['_EXTENSIONCTEPREVIEW']._serialized_start=1632
  _globals['_EXTENSIONCTEPREVIEW']._serialized_end=1866
  _globals['_EXTENSIONLINEAGETABCLICKED']._serialized_start=1869
  _globals['_EXTENSIONLINEAGETABCLICKED']._serialized_end=2110
  _globals['_EXTENSIONCOLUMNLINEAGE']._serialized_start=2113
  _globals['_EXTENSIONCOLUMNLINEAGE']._serialized_end=2350
  _globals['_EXTENSIONSHOWCOMPILEDFILE']._serialized_start=2353
  _globals['_EXTENSIONSHOWCOMPILEDFILE']._serialized_end=2593
  _globals['_EXTENSIONMODELRENAME']._serialized_start=2596
  _globals['_EXTENSIONMODELRENAME']._serialized_end=2831
  _globals['_EXTENSIONCOLUMNRENAME']._serialized_start=2834
  _globals['_EXTENSIONCOLUMNRENAME']._serialized_end=3070
  _globals['_EXTENSIONUSEDBUILDMENU']._serialized_start=3073
  _globals['_EXTENSIONUSEDBUILDMENU']._serialized_end=3336
  _globals['_EXTENSIONGETSUPPORTPOPUPSHOWN']._serialized_start=3339
  _globals['_EXTENSIONGETSUPPORTPOPUPSHOWN']._serialized_end=3605
  _globals['_EXTENSIONGETSUPPORTCLICKED']._serialized_start=3608
  _globals['_EXTENSIONGETSUPPORTCLICKED']._serialized_end=3871
  _globals['_EXTENSIONGETSUPPORTFORMSHOWN']._serialized_start=3874
  _globals['_EXTENSIONGETSUPPORTFORMSHOWN']._serialized_end=4139
  _globals['_EXTENSIONGETSUPPORTUNVERIFIEDNOTICESHOWN']._serialized_start=4142
  _globals['_EXTENSIONGETSUPPORTUNVERIFIEDNOTICESHOWN']._serialized_end=4419
  _globals['_EXTENSIONGETSUPPORTFORMSUBMITTED']._serialized_start=4422
  _globals['_EXTENSIONGETSUPPORTFORMSUBMITTED']._serialized_end=4708
  _globals['_EXTENSIONGETSUPPORTFORMCANCELLED']._serialized_start=4711
  _globals['_EXTENSIONGETSUPPORTFORMCANCELLED']._serialized_end=4980
  _globals['_EXTENSIONGETSUPPORTPANELCLOSED']._serialized_start=4983
  _globals['_EXTENSIONGETSUPPORTPANELCLOSED']._serialized_end=5250
  _globals['_EXTENSIONCOMPAREVIEWED']._serialized_start=5253
  _globals['_EXTENSIONCOMPAREVIEWED']._serialized_end=5508
  _globals['_EXTENSIONCOMPARESTARTED']._serialized_start=5511
  _globals['_EXTENSIONCOMPARESTARTED']._serialized_end=5787
  _globals['_EXTENSIONCOMPAREFINISHED']._serialized_start=5790
  _globals['_EXTENSIONCOMPAREFINISHED']._serialized_end=6137
  _globals['_EXTENSIONREGISTRATIONMESSAGEDISMISSED']._serialized_start=6140
  _globals['_EXTENSIONREGISTRATIONMESSAGEDISMISSED']._serialized_end=6410
  _globals['_EXTENSIONREGISTERSTARTED']._serialized_start=6413
  _globals['_EXTENSIONREGISTERSTARTED']._serialized_end=6776
  _globals['_EXTENSIONREGISTRATIONURLATTEMPTED']._serialized_start=6779
  _globals['_EXTENSIONREGISTRATIONURLATTEMPTED']._serialized_end=7120
  _globals['_EXTENSIONREGISTRATIONCOMPLETED']._serialized_start=7123
  _globals['_EXTENSIONREGISTRATIONCOMPLETED']._serialized_end=7570
  _globals['_EXTENSIONREGISTRATIONTIMEDOUT']._serialized_start=7573
  _globals['_EXTENSIONREGISTRATIONTIMEDOUT']._serialized_end=7970
  _globals['_EXTENSIONREGISTRATIONERRORED']._serialized_start=7973
  _globals['_EXTENSIONREGISTRATIONERRORED']._serialized_end=8402
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dbtlabs/proto/public/v1/common/vortex_options.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3dbtlabs/proto/public/v1/common/vortex_options.proto\x12\x10v1.public.common\x1a google/protobuf/descriptor.proto*\xa8\x02\n\x16VortexIcebergNamespace\x12(\n$VORTEX_ICEBERG_NAMESPACE_UNSPECIFIED\x10\x00\x12,\n(VORTEX_ICEBERG_NAMESPACE_COST_MONITORING\x10\x01\x12#\n\x1fVORTEX_ICEBERG_NAMESPACE_FUSION\x10\x02\x12&\n\"VORTEX_ICEBERG_NAMESPACE_TELEMETRY\x10\x03\x12 \n\x1cVORTEX_ICEBERG_NAMESPACE_DLQ\x10\x04\x12#\n\x1fVORTEX_ICEBERG_NAMESPACE_MANTLE\x10\x05\x12\"\n\x1eVORTEX_ICEBERG_NAMESPACE_CODEX\x10\x06:h\n\x10vortex_namespace\x12\x1f.google.protobuf.MessageOptions\x18\xeb\xd4\x03 \x01(\x0e\x32(.v1.public.common.VortexIcebergNamespace\x88\x01\x01:?\n\x11vortex_table_name\x12\x1f.google.protobuf.MessageOptions\x18\xec\xd4\x03 \x01(\t\x88\x01\x01:D\n\x16vortex_partition_field\x12\x1f.google.protobuf.MessageOptions\x18\xed\xd4\x03 \x01(\r\x88\x01\x01:E\n\x17vortex_write_to_iceberg\x12\x1f.google.protobuf.MessageOptions\x18\xef\xd4\x03 \x01(\x08\x88\x01\x01:<\n\x0evortex_enabled\x12\x1f.google.protobuf.MessageOptions\x18\xf0\xd4\x03 \x01(\x08\x88\x01\x01\x42\x33Z1github.com/dbt-labs/proto-golang/v1/public/commonb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dbtlabs.proto.public.v1.common.vortex_options_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z1github.com/dbt-labs/proto-golang/v1/public/common'
  _globals['_VORTEXICEBERGNAMESPACE']._serialized_start=108
  _globals['_VORTEXICEBERGNAMESPACE']._serialized_end=404
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dbtlabs/proto/public/v1/events/fusion/deps/deps.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n5dbtlabs/proto/public/v1/events/fusion/deps/deps.proto\x12\x1cv1.public.events.fusion.deps\"\xb6\x01\n\x0e\x44\x65psAddPackage\x12\x14\n\x0cpackage_name\x18\x01 \x01(\t\x12?\n\x0cpackage_type\x18\x02 \x01(\x0e\x32).v1.public.events.fusion.deps.PackageType\x12\x1c\n\x0fpackage_version\x18\x03 \x01(\tH\x00\x88\x01\x01\x12\x1b\n\x13\x64\x62t_core_event_code\x18\x04 \x01(\tB\x12\n\x10_package_version\"\x8c\x02\n\x14\x44\x65psPackageInstalled\x12\x19\n\x0cpackage_name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12?\n\x0cpackage_type\x18\x02 \x01(\x0e\x32).v1.public.events.fusion.deps.PackageType\x12\x1c\n\x0fpackage_version\x18\x03 \x01(\tH\x01\x88\x01\x01\x12 \n\x13package_url_or_path\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x1b\n\x13\x64\x62t_core_event_code\x18\x05 \x01(\tB\x0f\n\r_package_nameB\x12\n\x10_package_versionB\x16\n\x14_package_url_or_path\"1\n\x18\x44\x65psAllPackagesInstalled\x12\x15\n\rpackage_count\x18\x01 \x01(\x04*\xa3\x01\n\x0bPackageType\x12\x1c\n\x18PACKAGE_TYPE_UNSPECIFIED\x10\x00\x12\x14\n\x10PACKAGE_TYPE_HUB\x10\x01\x12\x14\n\x10PACKAGE_TYPE_GIT\x10\x02\x12\x16\n\x12PACKAGE_TYPE_LOCAL\x10\x03\x12\x18\n\x14PACKAGE_TYPE_PRIVATE\x10\x04\x12\x18\n\x14PACKAGE_TYPE_TARBALL\x10\x05\x42?Z=github.com/dbt-labs/proto-golang/v1/public/events/fusion/depsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dbtlabs.proto.public.v1.events.fusion.deps.deps_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z=github.com/dbt-labs/proto-golang/v1/public/events/fusion/deps'
  _globals['_PACKAGETYPE']._serialized_start=595
  _globals['_PACKAGETYPE']._serialized_end=758
  _globals['_DEPSADDPACKAGE']._serialized_start=88
  _globals['_DEPSADDPACKAGE']._serialized_end=270
  _globals['_DEPSPACKAGEINSTALLED']._serialized_start=273
  _globals['_DEPSPACKAGEINSTALLED']._serialized_end=541
  _globals['_DEPSALLPACKAGESINSTALLED']._serialized_start=543
  _globals['_DEPSALLPACKAGESINSTALLED']._serialized_end=592
# @@protoc_insertion_point(module_scope)
